Crate opentalk_types_api_common

Crate opentalk_types_api_common 

OpenTalk API common data types

Modules

error
Definition of error related types used in the OpenTalk API
module_assets
Types related to the asset storage API
pagination
Pagination types
result
Definition of results and related helper types used in the OpenTalk API
users
This module contains types that are used in OpenTalk API users endpoints.