Crate opentalk_types_api_common

Crate opentalk_types_api_common 

OpenTalk API common data types

Modules

error
Definition of error related types used in the OpenTalk API
pagination
Pagination types
result
Definition of results and related helper types used in the OpenTalk API