OpenTalk API common data types
Modules
- error
- Definition of error related types used in the OpenTalk API
- pagination
- Pagination types
- result
- Definition of results and related helper types used in the OpenTalk API
OpenTalk API common data types